#!/bin/sh

############################################################
# Variables
############################################################

STAGING="roadnav.dmg.staging"
TMPDMG="tmproadnav.dmg"

############################################################
# Build Roadnav
############################################################

cd ..
test -f config.h || ./configure $1 $2 $3 $4 $5 $6 $7 $8 $9 || exit 1

cd src
make roadnav.app || exit 1

VERSION=`grep "define VERSION" ../config.h | cut -f 3 -d " " | cut -f 2 -d \"`
DMG="roadnav-$VERSION.dmg"

############################################################
# Create and populate staging area
############################################################

mkdir "$STAGING"

cp -R roadnav.app "$STAGING"
cp ../AUTHORS "$STAGING"
cp ../ChangeLog "$STAGING"
cp ../README "$STAGING"
cp ../COPYING "$STAGING"
cp ../INSTALL "$STAGING"
cp ../NEWS "$STAGING"
cp ../TODO "$STAGING"

############################################################
# Calculate size
############################################################

SIZE=`du -sk "$STAGING" | cut -f 1 -d "	"`
SIZE=`/bin/expr $SIZE / 1000 + 2`

############################################################
# Create disk image
############################################################

rm -f "$TMPDMG"
hdiutil create "$TMPDMG" -megabytes $SIZE -fs HFS -volname Roadnav
VOL=`hdid "$TMPDMG" | grep "HFS" | cut -f 3 -d "	"`

cp -R "$STAGING"/* "$VOL"
cp -R "$STAGING"/* "$VOL"
hdiutil eject "$VOL"

############################################################
# Compress disk image
############################################################

rm -f "$DMG"
hdiutil convert "$TMPDMG" -format UDZO -o "$DMG"
rm -f "$TMPDMG"

############################################################
# Verify
############################################################

VOL=`hdid "$DMG" | grep "HFS" | cut -f 3 -d "	"`

CMP=`diff -r "$VOL" "$STAGING" | grep -v "\.Trashes"`

hdiutil eject "$VOL"

if [ "$CMP" != "" ]
then
	echo ---
	echo $CMP
	echo ---
	rm -f $DMG
fi

############################################################
# Clean up
############################################################

rm -rf "$STAGING"

mv "$DMG" ..
