/*
 *  Roadnav
 *  ColorPickerControl.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This file contains a control that shows what color is selected, and allows 
/// the user to change that color by clicking on the control.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef COLORPICKERCONTROL_H
#define COLORPICKERCONTROL_H

#include <wx/wx.h>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief wxControl that allows the user to pick a color
///
/// The selected color appears in a box, which when clicked brings up a 
/// wxColourDialog box allowing the user to select a new color.
///
//////////////////////////////////////////////////////////////////////////////
class ColorPickerControl : public wxControl
{
	public:
		ColorPickerControl();
		ColorPickerControl(wxWindow* parent, wxWindowID id, wxPoint pt, wxSize sz);
	
		void SetColor(wxColour clrColor);
		wxColour GetColor();

	private:
		void OnPaint(wxPaintEvent& event);
		void OnLeftUp(wxMouseEvent& event);
	
		/// Here we have the color the user has selected.
		wxColour m_clrSelection; 

		DECLARE_EVENT_TABLE()
		DECLARE_DYNAMIC_CLASS(ColorPickerControl);
};

#endif
