/*
 *  Roadnav
 *  CompassControl.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the CompassControl class - a control that graphically shows 
/// a direction
///
//////////////////////////////////////////////////////////////////////////////

#ifndef COMPASSCONTROL_H
#define COMPASSCONTROL_H

#include <wx/wx.h>

DECLARE_EVENT_TYPE(wxEVT_SAFE_REFRESH, -1)

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Graphically represents a direction
///
//////////////////////////////////////////////////////////////////////////////
class CompassControl : public wxControl
{
	public:
		CompassControl();
		CompassControl(wxWindow* parent, wxWindowID id = -1, wxPoint pt = wxDefaultPosition, wxSize sz = wxDefaultSize);

		void SetDirection(double fHeading);
		static void DrawCompass(wxDC * dc, wxColour clrBackground, wxColour clrForeground, double fHeading, wxPoint ptTopLeft, wxSize szSize);
	
	private:
		void SafeRefresh();
		void OnSafeRefresh(wxCommandEvent & event);
		void OnPaint(wxPaintEvent& event);
	
		/// Heading to display in degrees
		double m_fHeading;
	
		DECLARE_EVENT_TABLE()
		DECLARE_DYNAMIC_CLASS(CompassControl);
};

#endif
