/*
 *  Roadnav
 *  DirectionsFrame.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This frame is responsible for showing and verbalizing real time
/// directions to a place the user specifies.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef DIRECTIONSFRAME_H
#define DIRECTIONSFRAME_H

#include <wx/wx.h>

#include "libroadnav/Point.h"
#include "libroadnav/MapLookup.h"
#include "libroadnav/MapControlData.h"

#include <vector>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief This wxFrame supplies directions to a user selected place
///
//////////////////////////////////////////////////////////////////////////////
class DirectionsFrame : public wxFrame
{
	public:
		DirectionsFrame(class MapFrame * pfrmMap);

		~DirectionsFrame();
		
		bool Setup();
		void OnGPSUpdate(bool bEnabled, bool bActive, bool bLocked, Point pt, double fSpeed, double fHeading, wxString strLockType, int nSat, Address adrGPS);
		virtual bool SetBackgroundColour(const wxColour& colour);
		virtual bool SetForegroundColour(const wxColour& colour);
		virtual bool SetFont(const wxFont& font);

	private:
		void OnClose(wxCloseEvent& event);
		bool ComputePath();

		IMapControlData * m_pcRecords;
	
		/// Pointer to parent
		class MapFrame * m_pfrmMap;

		/// The last phrase to be verbalized
		wxString m_strLastNext;

		/// Starting address
		Address m_sStart;

		/// Destination address
		Address m_sEnd;

		/// Should these directions update in live time in response to the GPS unit?
		bool m_bLiveMode;

		// GPS info
		bool m_bGPSLock;
		Point m_ptGPS;
		double m_fGPSHeading;
		double m_fGPSSpeed;
		
		bool m_bLockOutGPSUpdate;

		/// Font used in text box
		wxFont m_fntText;

		/// Current path in record #s
		std::vector<tRecordID> m_vrPath;

		/// Pointer to text control
		wxTextCtrl * m_pctlText;
			
		wxColour m_clrBackground;
		wxColour m_clrText;

		DECLARE_EVENT_TABLE()
};

#endif
