/*
 *  Roadnav
 *
 *  EditThemeDialog.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains a dialog box used to edit a specific theme.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef EDITTHEMEDIALOG_H
#define EDITTHEMEDIALOG_H

#include <vector>

#include "ColorPickerControl.h"
#include "libroadnav/MapAppearanceSettings.h"
#include "libroadnav/MapControlData.h"

#define EDITTHEMEDIALOG_MAX_DETAILLEVELS		32

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements a dialog box used to edit a specific theme
///
//////////////////////////////////////////////////////////////////////////////
class EditThemeDialog : public wxDialog
{
	public:
		EditThemeDialog(wxWindow * pParent, const wxString & strTheme, const MapAppearanceSettings & cTheme, IMapControlData * pMapControlData);

		MapAppearanceSettings GetTheme();
		wxString GetThemeName();
	
	private:
		void RecordSettings();
		wxArrayString GetRecordTypeNames();

		void OnCheckBox(wxEvent & event);
		void OnOk(wxCommandEvent& event);
		void OnRecordTypeChange(wxCommandEvent & event);
		void OnDetailLevelChange(wxCommandEvent & event);

		/// Map control data - mostly used to figure out what the detail levels are called
		IMapControlData * m_pMapControlData;

		/// last record type that was selected
		int m_iLastRecordType;

		/// Theme being edited
		MapAppearanceSettings m_Theme;
		
		/// Name of theme being edited
		wxString m_strTheme;
	
		/// Control containing name of theme being edited
		wxTextCtrl* m_pctlThemeName;
	
		/// Contains which setting is being changed
		wxComboBox * m_pctlRecordType;
	
		/// Label color selected
		ColorPickerControl * m_pctlLabelColor[EDITTHEMEDIALOG_MAX_DETAILLEVELS];
		
		/// Line color selected
		ColorPickerControl * m_pctlLineColor[EDITTHEMEDIALOG_MAX_DETAILLEVELS];
		
		/// Label visible checkbox
		wxCheckBox * m_pctlLabelVisible[EDITTHEMEDIALOG_MAX_DETAILLEVELS];
		
		/// Label font size text control
		wxTextCtrl * m_pctlLabelFontSize[EDITTHEMEDIALOG_MAX_DETAILLEVELS];

		/// Line visible checkbox
		wxCheckBox * m_pctlLineVisible[EDITTHEMEDIALOG_MAX_DETAILLEVELS];
		
		/// Line width text control
		wxTextCtrl * m_pctlLineWidth[EDITTHEMEDIALOG_MAX_DETAILLEVELS];

		DECLARE_EVENT_TABLE()
};

#endif
