/*
 *  Roadnav
 *  GPSFrame.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the GPSFrame class - a frame that has a single child - a
/// GPSControl.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef GPSFRAME_H
#define GPSFRAME_H

#include <wx/minifram.h>

#include "libroadnav/Point.h"
#include "GPSMonitorThread.h"
#include "SatelliteControl.h"

#define	TIMERID_REFRESH		1

//////////////////////////////////////////////////////////////////////////////
///
/// \brief wxFrame containing a GPSControl
///
//////////////////////////////////////////////////////////////////////////////
class GPSFrame : public wxFrame
{
	public:
		GPSFrame(class MapFrame * pfrmMap);

		~GPSFrame();
		
		void OnGPSUpdate(wxGPSEvent evGPS);
		void UpdateColors(wxColour clrForeground, wxColour clrBackground);
		
		virtual bool SetFont(const wxFont& font);
		virtual bool SetBackgroundColour(const wxColour& colour);
		virtual bool SetForegroundColour(const wxColour& colour);

		void SafeRefresh();

	private:
		void OnSafeRefresh(wxCommandEvent & event);
		void OnPaint(wxPaintEvent& event);
		void OnEraseBackground(wxEraseEvent& event);
		void OnClose(wxCloseEvent& event);
	
		/// Pointer to parent
		class MapFrame * m_pfrmMap;
		
		wxStaticText * m_pctlStatusLabel;
		wxStaticText * m_pctlPositionLabel;
		wxStaticText * m_pctlSpeedLabel;
		wxStaticText * m_pctlHeadingLabel;
		wxStaticText * m_pctlSatellitesLabel;
		
		wxStaticText * m_pctlStatus;
		wxStaticText * m_pctlPosition;
		wxStaticText * m_pctlSpeed;
		wxStaticText * m_pctlHeading;
		wxStaticText * m_pctlSatellites;
		
		SatelliteControl * m_pctlSatelliteMap;
			
		DECLARE_EVENT_TABLE()
};

#endif
