/*
 *  Roadnav
 *  GPSInterface_None.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Dummy gps interface module for when no GPS unit is installed.
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#pragma warning(disable: 4800)
#endif

#include <wx/wx.h>

#include "GPSInterface_None.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Constructor - do nothing
///
//////////////////////////////////////////////////////////////////////////////
GPSInterface_None::GPSInterface_None()
{
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Destructor - do nothing
///
//////////////////////////////////////////////////////////////////////////////
GPSInterface_None::~GPSInterface_None()
{
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Returns the name of this GPS interface (None).
///
//////////////////////////////////////////////////////////////////////////////
wxString GPSInterface_None::Name()
{
	return wxT("None");
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Always returns that GPS is disabled after sleeping for one second.
///
/// \param pGPSEvent		Receives gps data.
///
/// \return					Status - always returns GPSStatusOK.
///
//////////////////////////////////////////////////////////////////////////////
IGPSInterface::EGPSStatus GPSInterface_None::GetData(wxGPSEvent * pGPSEvent)
{
	wxThread::Sleep(1000);
	
	*pGPSEvent = wxGPSEvent(false, false, false, Point(0, 0), 0, 0, wxT("None"), 0, NULL, 0, wxT(""));

	return GPSStatusOK;
}


//////////////////////////////////////////////////////////////////////////////
///
/// \brief Returns an explanation of the last error.
///
//////////////////////////////////////////////////////////////////////////////
wxString GPSInterface_None::GetLastError()
{
	return m_strLastError;
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Always reports that autodetection is not supported on this class.
///
//////////////////////////////////////////////////////////////////////////////
IGPSInterface::EGPSStatus GPSInterface_None::AutoDetect(wxThread * pThread)
{
	m_strLastError = wxT("Autodetection not supported");
	return GPSStatusAutoDetectionNotSupported;
}
