/*
 *  Roadnav
 *  GPSInterface_Serial.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// NMEA serial gps interface module.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef GPSINTERFACE_SERIAL_H
#define GPSINTERFACE_SERIAL_H

#include "SerialIO.h"

#ifdef ROADNAV_SERIAL_SUPPORT

#include <wx/datetime.h>

#include <vector>

#include "GPSInterface.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements serial GPS interface
///
//////////////////////////////////////////////////////////////////////////////
class GPSInterface_Serial : public IGPSInterface
{
	public:
		GPSInterface_Serial();
		virtual ~GPSInterface_Serial();
		
		virtual wxString Name();
		virtual EGPSStatus GetData(wxGPSEvent * pGPSEvent);
		virtual wxString GetLastError();
		virtual EGPSStatus AutoDetect(wxThread * pThread);
		
		static bool VerifyGPSChecksum(wxString strSentence);
		
	private:

		/// Last known heading
		double m_fLastHeading;

		/// Time of last valid GPS sentence
		wxDateTime m_tLastGPSSentence;
		
		/// Time of last GPS lock
		wxDateTime m_tLastGPSLock;

		/// Time of last serial activity
		wxDateTime m_tLastSerialActivity;


		/// Receive buffer
		char m_szBuffer[1024];


		/// GPS coordinates
		Point m_ptGPS;
		
		/// Speed
		double m_fSpeed;
		
		/// Heading
		double m_fHeading;


		/// Minimum speed the vehicle must be going in order to update the heading.
		double m_fMinimumSpeedForHeading;

		/// If the GPGGA sentence has been seen
		bool m_bSeenGPGGA;
		
		/// If the GPRMC sentence has been seen
		bool m_bSeenGPRMC;

		/// Number of satellites used for lock
		long m_nSatellites;

		/// String describing lock type
		wxString m_strFixType;
		
		/// Satellites visible
		SSatelliteInfo m_arSatellitesVisible[MAX_GPS_SATELLITES];
		int m_nSatellitesVisible;
		
		/// If serial I/O init function has been called.
		bool m_bSerialInitialized;

		/// Last error message
		wxString m_strLastError;
		
		wxThread * m_pThread;
};

#endif // #ifdef ROADNAV_SERIAL_SUPPORT

#endif // #ifndef GPSINTERFACE_SERIAL_H
