/*
 *  Roadnav
 *  GPSInterface_Simulated.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Simulated gps interface module.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef GPSINTERFACE_SIMULATED_H
#define GPSINTERFACE_SIMULATED_H

#include "libroadnav/Debug.h"

#if defined(__WXDEBUG__) || defined(LIBROADNAV_DEBUG)
#define HAVE_SIMULATED_GPS_SUPPORT
#endif

#ifdef HAVE_SIMULATED_GPS_SUPPORT

#include "GPSInterface.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements simulated gps interface
///
//////////////////////////////////////////////////////////////////////////////
class GPSInterface_Simulated : public IGPSInterface
{
	public:
		GPSInterface_Simulated();
		virtual ~GPSInterface_Simulated();
		
		virtual wxString Name();
		virtual EGPSStatus GetData(wxGPSEvent * pGPSEvent);
		virtual wxString GetLastError();
		virtual EGPSStatus AutoDetect(wxThread * pThread);
		
	private:
		/// Simulated heading
		double m_fHeading;
		
		/// Simulated speed
		double m_fSpeed;
		
		/// Simulated coordinates
		Point m_ptGPS;
		
		/// Last error message
		wxString m_strLastError;
};

#endif // #ifdef HAVE_SIMULATED_GPS_SUPPORT

#endif // #ifndef GPSINTERFACE_SIMULATED_H
