/*
 *  Roadnav
 *  GPSMonitorThread.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains a thread that reads the current coordinates from a NMEA GPS 
/// unit and passes this to the update thread.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef GPSMONITORTHREAD_H
#define GPSMONITORTHREAD_H

#include <wx/wx.h>
#include <wx/thread.h>
#include <wx/event.h>
#include <wx/socket.h>

#include <vector>

#include "libroadnav/Point.h"
#include "SerialIO.h"
#include "GPSInterface.h"
#include "GPSInterface_GPSD.h"
#include "GPSInterface_Serial.h"
#include "GPSInterface_Simulated.h"
#include "GPSInterface_None.h"

enum EGPSType
{
	GPSTypeNone = 0,
	
#ifdef ROADNAV_SERIAL_SUPPORT
	GPSTypeSerial = 1,
#endif

#ifdef HAVE_LIBGPS
	GPSTypeGPSD = 2,
#endif

#ifdef HAVE_SIMULATED_GPS_SUPPORT
	GPSTypeSimulated = 3,
#endif

	GPSTypeAutoDetect = 4,
	GPSTypeAutoDetectInProgress = 5,
};

#define GPSTYPE_MAX		GPSTypeAutoDetectInProgress

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Monitors a serial port for NMEA sentences from a GPS unit.
///
//////////////////////////////////////////////////////////////////////////////
class GPSMonitorThread : public wxThread
{
	public:
		GPSMonitorThread(class MapFrame * pFrame);
		virtual void * Entry();
		IGPSInterface * CreateGPSObject(EGPSType eGPSType);

		static EGPSType GetGPSType();
		static void SetGPSType(EGPSType eType);

		static EGPSType GetLastSuccessfulAutoDetectGPSType();
		static void SetLastSuccessfulAutoDetectGPSType(EGPSType eType);

	private:
		/// Pointer to parent
		class MapFrame * m_pFrame;
};

#endif
