/*
 *  Roadnav
 *  KeyboardDialog.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This file contains the KeyboardDialog class, a dialog that shows an
/// onscreen keyboard, allowing data to be entered into a wxTextCtrl
/// without the use of a real keyboard.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef KEYBOARDDIALOG_H
#define KEYBOARDDIALOG_H

#include "libroadnav/AutoComplete.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Shows an onscreen keyboard, allowing a wxTextCtrl to be used
/// on a computer without a real keyboard.
///
//////////////////////////////////////////////////////////////////////////////
class KeyboardDialog : public wxDialog
{
	public:
		KeyboardDialog(wxWindow *parent, wxString strTitle, wxTextCtrl * pctlText, wxColour clrBackground, wxColour clrForeground, IAutoComplete * pcAutoComplete);
	
		wxMutex m_mtxAutoCompleteThreadControl;
		wxString m_strAutoCompleteThreadResult;
		bool m_bAutoCompleteThreadRunning;
		bool m_bAutoCompleteThreadRunAgain;
	
	private:
		void OnKBButtonPress(wxEvent & event);
		void OnCancel(wxCommandEvent & event);
		void OnOk(wxCommandEvent & event);
		void OnAutoCompleteButton(wxCommandEvent & event);
		void OnAutoCompleteTimer(wxTimerEvent& event);
		void OnThisTextControlChanged(wxCommandEvent & event);

		/// Text control from parent window that's being filled in
		wxTextCtrl * m_pctlText;
		
		/// Text control in this window that's being filled in
		wxTextCtrl * m_pctlThisText;
		
		/// Default font used in this dialog
		wxFont m_fntThis;
		
		wxButton * m_pbtnAutoComplete;
		
		IAutoComplete * m_pcAutoComplete;
		wxTimer * m_ptmrAutoComplete;
		
		DECLARE_EVENT_TABLE()
};

#endif
