/*
 *  Roadnav
 *  LCDprocSettings.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the various classes used to represent the LCDproc related
/// settings.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef LCDPROCSETTINGS_H
#define LCDPROCSETTINGS_H

#include <vector>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Class that contains all of the LCDproc related Roadnav settings
/// for a single widget.
///
//////////////////////////////////////////////////////////////////////////////
class LCDprocWidgetInfo
{
	public:
		LCDprocWidgetInfo();
		void Read();
		void Write();
		
		/// Row of this widget. 1 = top row, 2 = second row, etc.
		int m_iRow;
		
		/// Column of this widget. 1 = left column, 2 = second column, etc.
		int m_iCol;

		/// Type of widget - Text, Title, Horizontal Bar, or Vertical Bar
		wxString m_strType;

		/// Value of widget - may contain a mangled variable name or static text.
		/// Has no effect for horizontal/vertical bars.
		wxString m_strValue;
};

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Class that contains all of the LCDproc related Roadnav settings
/// for a single screen.
///
//////////////////////////////////////////////////////////////////////////////
class LCDprocScreenInfo
{ 
	public:
		LCDprocScreenInfo();
		void Read();
		void Write();

		/// Name of this screen		
		wxString m_strName;
		
		/// Vector of widgets belonging to this screen.
		std::vector<LCDprocWidgetInfo> m_vWidgets;
};

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Class that contains all of the LCDproc related Roadnav settings.
///
//////////////////////////////////////////////////////////////////////////////
class LCDprocSettings
{
	public:
		LCDprocSettings();
		void Read();
		void Write();
		
		/// Is LCDproc support enabled?
		bool m_bLCDprocEnabled;

		/// Host and port of the LCDproc server in Host:Port format
		wxString m_strHostAndPort;
		
		/// Vector of the configured screens.
		std::vector<LCDprocScreenInfo> m_vScreens;
};

#endif
