/*
 *  Roadnav
 *  LocationPageAddress.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// \brief This location page allows a street address to be entered.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef LOCATIONPAGEADDRESS_H
#define LOCATIONPAGEADDRESS_H

#include <wx/notebook.h>

#include <map>

#include "libroadnav/Address.h"
#include "libroadnav/MapControl.h"
#include "libroadnav/MapState.h"
#include "libroadnav/MapZip.h"
#include "libroadnav/MapLookup.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief This location page allows a street address to be entered.
///
//////////////////////////////////////////////////////////////////////////////
class LocationPageAddress : public wxPanel
{
	public:
		LocationPageAddress(wxWindow *parent, MapControl * pctlMap);
		Address GetAddress(wxString * pstrErrorMsg, bool bRoadsOnly);
		void SetAddress(Address cAddress);
		bool MayClose(bool bRoadsOnly);
		void UpdateAutoCompletionObjects(bool bRoadsOnly);

		/// Street address specified by user
		wxString m_strStreet;
		
		/// City specified by user
		wxString m_strCity;
		
		/// State specified by user
		wxString m_strState;
		
		std::map<wxWindow *,IAutoComplete *> m_mapWndToAutoComplete;

	private:

		/// Street name text control
		wxTextCtrl * m_ctlStreet;
	
		/// City text control
		wxTextCtrl * m_ctlCity;
	
		/// State name text control
		wxTextCtrl * m_ctlState;

		/// Pointer to the map control
		MapControl * m_pctlMap;
		
		wxString m_strErrorMsg;
		Address m_cAddress;
		
		AutoComplete_State m_cAutoCompleteState;
		AutoComplete_City m_cAutoCompleteCity;
		AutoComplete_Street m_cAutoCompleteStreet;
		
		DECLARE_EVENT_TABLE()
};

#endif
