/*
 *  Roadnav
 *  MapEventExtender.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// This file contains an event handler that extends map control events
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPEVENTEXTENDER_H
#define MAPEVENTEXTENDER_H

#include <wx/event.h>

#include "libroadnav/Point.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Enumeration item describing the mode of the mouse (zoom, measure,
/// normal).
///
//////////////////////////////////////////////////////////////////////////////
enum EToolMode 
{
	toolNone,
	toolMeasure,
	toolZoom 
};

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Provides the measure and zoom tool
///
//////////////////////////////////////////////////////////////////////////////
class MapEventExtender : public wxEvtHandler
{
	public:
		MapEventExtender(class MapFrame * pFrame, class MapControl * pMap);

	private:
		class MapFrame * m_pFrame;
		class MapControl * m_pMap;

		// state variables for measuring
		bool m_bMeasuring;
		bool m_bZooming;
		Point m_ptStart; // Start point in positional coordinates
		wxPoint m_Start;
		wxPoint m_Last;

		void OnLButtonDown(wxMouseEvent& event);
		void OnMouseMove(wxMouseEvent& event);
		void OnLButtonUp(wxMouseEvent& event);

		DECLARE_EVENT_TABLE()
};

#endif
