/*
 *  Roadnav
 *  PreferencesDialog.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the preferences dialog box.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef PREFERENCESDIALOG_H
#define PREFERENCESDIALOG_H

#include "libroadnav/MapControl.h"

#include "PreferencesPageGeneral.h"
#include "PreferencesPageGPS.h"
#include "PreferencesPageTTS.h"
#include "PreferencesPageThemes.h"
#include "PreferencesPageURLs.h"
#include "PreferencesPageUnits.h"
#include "PreferencesPageLCDproc.h"
#include "PreferencesPageRouting.h"
#include "PreferencesPageOSM.h"
#include "PreferencesPageScripting.h"
#include "PreferencesPageProxy.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements the preferences dialog box
///
//////////////////////////////////////////////////////////////////////////////
class PreferencesDialog : public wxDialog
{
	public:
		PreferencesDialog(wxWindow *parent, MapControl * pctlMap, wxFont * pFont, IMapControlData * pMapControlData, ThemeManager * pThemeManager);
	
	private:
		PreferencesPageGeneral * m_pwndGeneral;
		PreferencesPageGPS * m_pwndGPS;
		PreferencesPageTTS * m_pwndTTS;
		PreferencesPageThemes* m_pwndThemes;
		PreferencesPageURLs * m_pwndURLs;
		PreferencesPageUnits * m_pwndUnits;
		PreferencesPageLCDproc * m_pwndLCDproc;
		PreferencesPageRouting * m_pwndRouting;
#ifdef USE_OPENSTREETMAP
		PreferencesPageOSM * m_pwndOSM;
#endif
#ifdef USE_SCRIPTING
		PreferencesPageScripting * m_pwndScripting;
#endif
		PreferencesPageProxy * m_pwndProxy;

		void OnOk(wxCommandEvent& event);
		void OnCancel(wxCommandEvent& event);

		void OnTimer(wxTimerEvent& event);
		void OnKeyboard(wxCommandEvent & event);

		/// Last wxTextCtrl to have focus
		wxTextCtrl * m_pwndFocused;

		/// 100ms timer used to track which wxTextCtrl has focus
		wxTimer * m_Timer;
		
		/// IMapControlData from MapFrame
		IMapControlData * m_pMapControlData;

		/// Theme manager
		ThemeManager * m_pThemeManager;
		
		MapControl * m_pctlMap;

		DECLARE_EVENT_TABLE()
};

#endif
