/*
 *  Roadnav
 *
 *  PreferencesPageGPS.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the GPS page of the preferences dialog box.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef PREFERENCESPAGEGPS_H
#define PREFERENCESPAGEGPS_H

#include <wx/notebook.h>

#include "SerialIO.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements the GPS page of the preferences dialog box
///
//////////////////////////////////////////////////////////////////////////////
class PreferencesPageGPS : public wxPanel
{
	public:
		PreferencesPageGPS(wxWindow *parent);
		void OnOk(wxCommandEvent& event);

		void OnGPSTypeChange(wxCommandEvent & event);	
		void OnIconBrowse(wxCommandEvent& event);
		
	private:
		/// Serial port of GPS unit
		wxComboBox * m_pctlGPSType;

#ifdef ROADNAV_SERIAL_SUPPORT
		/// Serial port of GPS unit
		wxComboBox * m_pctlSerialPort;
	
		/// Baud rate of GPS unit (typically 4800)
		wxComboBox * m_pctlBaudRate;
		
		/// Serial initialization string (e.g. ASTRAL for Tripmates)
		wxTextCtrl * m_pctlSerialInitString;
#endif

#ifdef HAVE_LIBGPS
		wxTextCtrl * m_pctlgpsdHost;
		wxTextCtrl * m_pctlgpsdPort;
		wxCheckBox * m_pctlgpsdCompatibilityCheck;
		wxCheckBox * m_pctlgpsdBufferingEnabled;
#endif

		wxCheckBox * m_pctlGPSCalloutBox;
		wxCheckBox * m_pctlGPSSmallLabel;
		wxCheckBox * m_pctlGPSArrow;
		wxTextCtrl * m_pctlGPSIcon;

		wxCheckBox * m_pctlRotateMapToMatchHeading;
		wxCheckBox * m_pctlKeepGPSCentered;
		wxCheckBox * m_pctlZoomBasedOnRoadType;

		DECLARE_EVENT_TABLE()
};

#endif
