/*
 *  Roadnav
 *  PreferencesPageLCDproc.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the LCDproc page of the preferences dialog box.
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#pragma warning(disable: 4800)
#endif

#include <wx/wx.h>

#include "App.h"
#include "PreferencesPageLCDproc.h"
#include "LCDprocInterface.h"

using namespace std;

enum
{
	idAdd,
	idUpdate,
	idDelete,
	idScreenSelection,
	idWidgetList
};

BEGIN_EVENT_TABLE(PreferencesPageLCDproc, wxPanel)
	EVT_COMBOBOX(idScreenSelection, PreferencesPageLCDproc::OnScreenSelection)
	EVT_TEXT(idScreenSelection, PreferencesPageLCDproc::OnScreenSelection)
	EVT_LISTBOX(idWidgetList, PreferencesPageLCDproc::OnWidgetSelection)
	EVT_BUTTON(idAdd, PreferencesPageLCDproc::OnWidgetAdd)
	EVT_BUTTON(idUpdate, PreferencesPageLCDproc::OnWidgetUpdate)
	EVT_BUTTON(idDelete, PreferencesPageLCDproc::OnWidgetDelete)
END_EVENT_TABLE()

//////////////////////////////////////////////////////////////////////////////
///
/// \brief PreferencesPageLCDproc constructor - create and initialize controls
///
//////////////////////////////////////////////////////////////////////////////
PreferencesPageLCDproc::PreferencesPageLCDproc(wxWindow *parent)
             : wxPanel(parent, -1, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL)
{
	wxFlexGridSizer * psizerWnd;
	wxFlexGridSizer * psizerTop;
	wxStaticBoxSizer * psizerBottom;
	wxFlexGridSizer * psizerWidgetList;
	wxFlexGridSizer * psizerWidgetSettings;
	wxFlexGridSizer * psizerRowCol;
	wxBoxSizer * psizerWidgetListActions;
	wxString strTmp;
	unsigned int iVariable;
	vector<wxString> vVariables;
	
	vVariables = GetLCDprocVariableNames();
	
	m_cActiveSettings = GetLCDprocSettings();
	
	psizerTop = new wxFlexGridSizer(2, 3, 10);

	//////////////////////////////////////////////////////////////////////////
	// "Enable LCDproc Support" label
	//////////////////////////////////////////////////////////////////////////
	psizerTop->Add(
		new wxStaticText(this, -1, wxT("Enable LCDproc Support")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Enable LCDproc Support" check box
	//////////////////////////////////////////////////////////////////////////

	m_pctlEnableLCDproc = new wxCheckBox(this, -1, wxT(""));
	m_pctlEnableLCDproc->SetValue(m_cActiveSettings.m_bLCDprocEnabled);

	psizerTop->Add(
		m_pctlEnableLCDproc,
		0,
		wxALIGN_LEFT,
		0
	);

	
	//////////////////////////////////////////////////////////////////////////
	// "Host and Port" label
	//////////////////////////////////////////////////////////////////////////
	psizerTop->Add(
		new wxStaticText(this, -1, wxT("Host and Port")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Host and Port" text control
	//////////////////////////////////////////////////////////////////////////

	m_pctlHostAndPort = new wxTextCtrl(this, -1, m_cActiveSettings.m_strHostAndPort, wxDefaultPosition, wxSize(250, -1));

	psizerTop->Add(
		m_pctlHostAndPort, 
		1,
		wxALIGN_LEFT,
		0
	);

	

	//////////////////////////////////////////////////////////////////////////
	// "Screen Selection" label
	//////////////////////////////////////////////////////////////////////////
	psizerTop->Add(
		new wxStaticText(this, -1, wxT("Screen Selection")),
		1,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Screen Selection" check box
	//////////////////////////////////////////////////////////////////////////

	m_pctlScreenSelection = new wxComboBox(this, idScreenSelection, wxT(""), wxDefaultPosition, wxSize(250, -1), 0, NULL, wxCB_DROPDOWN);

	psizerTop->Add(
		m_pctlScreenSelection, 
		1,
		wxALIGN_LEFT,
		0
	);

	//////////////////////////////////////////////////////////////////////////
	// Bottom half of the screen
	//////////////////////////////////////////////////////////////////////////

	psizerBottom = new wxStaticBoxSizer(wxHORIZONTAL, this, wxT("Screen Settings"));
	
	psizerWidgetSettings = new wxFlexGridSizer(1, 0, 10);

	//////////////////////////////////////////////////////////////////////////
	// "Type" label
	//////////////////////////////////////////////////////////////////////////
	psizerWidgetSettings->Add(
		new wxStaticText(this, -1, wxT("Widget Type")),
		1,
		wxALIGN_CENTER,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Type" combo box
	//////////////////////////////////////////////////////////////////////////

	m_pctlWidgetType = new wxComboBox(this, -1, wxT(""), wxDefaultPosition, wxSize(150, -1), 0, NULL, wxCB_READONLY);

	m_pctlWidgetType->Append(wxT("Text"));
	m_pctlWidgetType->Append(wxT("Title"));
	m_pctlWidgetType->Append(wxT("Horizontal Bar"));
	m_pctlWidgetType->Append(wxT("Vertical Bar"));
	
	m_pctlWidgetType->SetValue(wxT("Text"));

	psizerWidgetSettings->Add(
		m_pctlWidgetType, 
		1,
		wxALIGN_LEFT,
		0
	);

	
	
	//////////////////////////////////////////////////////////////////////////
	// Row/Column selection
	//////////////////////////////////////////////////////////////////////////

	psizerRowCol = new wxFlexGridSizer(2, 2, 10);

	//////////////////////////////////////////////////////////////////////////
	// "Row" label
	//////////////////////////////////////////////////////////////////////////
	psizerRowCol->Add(
		new wxStaticText(this, -1, wxT("Row")),
		1,
		wxALIGN_CENTER,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Column" label
	//////////////////////////////////////////////////////////////////////////
	psizerRowCol->Add(
		new wxStaticText(this, -1, wxT("Column")),
		1,
		wxALIGN_CENTER,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Row" text control
	//////////////////////////////////////////////////////////////////////////
	m_pctlWidgetRow = new wxTextCtrl(this, -1, wxT(""), wxDefaultPosition, wxSize(75, -1));

	psizerRowCol->Add(
		m_pctlWidgetRow, 
		1,
		wxALIGN_LEFT | wxGROW,
		0
	);

	//////////////////////////////////////////////////////////////////////////
	// "Column" text control
	//////////////////////////////////////////////////////////////////////////
	m_pctlWidgetColumn = new wxTextCtrl(this, -1, wxT(""), wxDefaultPosition, wxSize(75, -1));

	psizerRowCol->Add(
		m_pctlWidgetColumn, 
		1,
		wxALIGN_LEFT | wxGROW,
		0
	);

	psizerWidgetSettings->Add(psizerRowCol, 1, wxALL | wxGROW, 0);


	//////////////////////////////////////////////////////////////////////////
	// "Contents" label
	//////////////////////////////////////////////////////////////////////////
	psizerWidgetSettings->Add(
		new wxStaticText(this, -1, wxT("Widget Contents")),
		1,
		wxALIGN_CENTER,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Contents" combo box
	//////////////////////////////////////////////////////////////////////////

	m_pctlWidgetContents = new wxComboBox(this, -1, wxT(""), wxDefaultPosition, wxSize(150, -1), 0, NULL, 0);

	psizerWidgetSettings->Add(
		m_pctlWidgetContents, 
		1,
		wxALIGN_LEFT,
		0
	);

	for (iVariable = 0; iVariable < vVariables.size(); iVariable++)
		m_pctlWidgetContents->Append(vVariables[iVariable]);
	
	
	
	psizerWidgetList = new wxFlexGridSizer(2, 2, 10);
	
	//////////////////////////////////////////////////////////////////////////
	// "Widgets" label
	//////////////////////////////////////////////////////////////////////////
	psizerWidgetList->Add(
		new wxStaticText(this, -1, wxT("Widget List")),
		1,
		wxALIGN_CENTER,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Blank label
	//////////////////////////////////////////////////////////////////////////
	psizerWidgetList->Add(
		new wxStaticText(this, -1, wxT("")),
		1,
		wxALIGN_CENTER,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// "Widgets" list box
	//////////////////////////////////////////////////////////////////////////

	m_pctlWidgetList = new wxListBox(this, idWidgetList, wxDefaultPosition, wxSize(100, 100), 0, NULL, wxLB_SINGLE);

	psizerWidgetList->Add(
		m_pctlWidgetList, 
		1,
		wxALIGN_CENTER | wxGROW,
		0
	);

	
	//////////////////////////////////////////////////////////////////////////
	// Widget list actions - add, update, delete
	//////////////////////////////////////////////////////////////////////////
	psizerWidgetListActions = new wxBoxSizer(wxVERTICAL);
	
	psizerWidgetListActions->Add(
		new wxButton(this, idAdd, wxT("&Add")), 
		1, 
		wxALL | wxGROW, 
		0
	);

	psizerWidgetListActions->Add(
		new wxButton(this, idUpdate, wxT("&Update")), 
		1, 
		wxALL | wxGROW, 
		0
	);

	psizerWidgetListActions->Add(
		new wxButton(this, idDelete, wxT("&Delete")), 
		1, 
		wxALL | wxGROW, 
		0
	);
	psizerWidgetList->Add(psizerWidgetListActions, 1, wxALL | wxGROW, 0);

	//////////////////////////////////////////////////////////////////////////
	// Combine the sizers
	//////////////////////////////////////////////////////////////////////////
	psizerBottom->Add(psizerWidgetSettings, 1, wxALL | wxGROW, 10);
	psizerBottom->Add(psizerWidgetList, 1, wxALL | wxGROW, 10);
	
	psizerWnd = new wxFlexGridSizer(1, 2, 10);
	psizerWnd->Add(psizerTop, 1, wxALL | wxGROW, 10);
	psizerWnd->Add(psizerBottom, 1, wxALL | wxGROW, 10);
	
	//////////////////////////////////////////////////////////////////////////
	// Set up the sizer
	//////////////////////////////////////////////////////////////////////////

	//m_pctlPositionFormat->SetFocus();
	psizerWnd->Fit(this);
	SetSizer(psizerWnd);
	Layout();
	psizerWnd->SetSizeHints(this);
	
	UpdateScreenList();
	
	if (m_pctlScreenSelection->GetCount() > 0)
	{
		m_pctlScreenSelection->SetSelection(0);
		UpdateWidgetList();
	}
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Update the list of screens in the m_pctlScreenSelection combo box.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::UpdateScreenList()
{
	unsigned int iScreen;

	m_pctlScreenSelection->Clear();
	
	for (iScreen = 0; iScreen < m_cActiveSettings.m_vScreens.size(); iScreen++)
		m_pctlScreenSelection->Append(m_cActiveSettings.m_vScreens[iScreen].m_strName);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Update the list of widgets in the m_pctlWidgetList list box.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::UpdateWidgetList()
{
	int iScreen;
	
	iScreen = m_pctlScreenSelection->FindString(m_pctlScreenSelection->GetValue());
	
	m_pctlWidgetList->Clear();
	
	if (iScreen != wxNOT_FOUND && iScreen >= 0)
	{
		unsigned int iWidget;
		
		for (iWidget = 0; iWidget < m_cActiveSettings.m_vScreens[iScreen].m_vWidgets.size(); iWidget++)
			m_pctlWidgetList->Append(m_cActiveSettings.m_vScreens[iScreen].m_vWidgets[iWidget].m_strValue);
		
	}
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Ok was pressed .. save the settings
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::OnOk(wxCommandEvent& event)
{
	m_cActiveSettings.m_strHostAndPort = m_pctlHostAndPort->GetValue();
	m_cActiveSettings.m_bLCDprocEnabled = m_pctlEnableLCDproc->GetValue();

	SetLCDprocSettings(m_cActiveSettings);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Text was typed in the screen selection combo box - update the
/// widget list accordingly.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::OnScreenSelection(wxCommandEvent& event)
{
	UpdateWidgetList();
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief The user selected a widget from the list. Update the widget
/// settings on the screen with the settings for that widget.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::OnWidgetSelection(wxCommandEvent& event)
{
	int iScreen;
	int iWidget;
	
	iScreen = m_pctlScreenSelection->FindString(m_pctlScreenSelection->GetValue());
	
	iWidget = m_pctlWidgetList->GetSelection();
	
	if (iWidget == wxNOT_FOUND || iWidget < 0 || iScreen == wxNOT_FOUND || iScreen < 0)
	{
		m_pctlWidgetRow->SetValue(wxT(""));
		m_pctlWidgetColumn->SetValue(wxT(""));
		m_pctlWidgetType->SetValue(wxT("Text"));
		m_pctlWidgetContents->SetValue(wxT(""));
		
		return;
	}
		
	m_pctlWidgetRow->SetValue(wxString::Format(wxT("%d"), m_cActiveSettings.m_vScreens[iScreen].m_vWidgets[iWidget].m_iRow));
	m_pctlWidgetColumn->SetValue(wxString::Format(wxT("%d"), m_cActiveSettings.m_vScreens[iScreen].m_vWidgets[iWidget].m_iCol));
	m_pctlWidgetType->SetValue(m_cActiveSettings.m_vScreens[iScreen].m_vWidgets[iWidget].m_strType);
	m_pctlWidgetContents->SetValue(m_cActiveSettings.m_vScreens[iScreen].m_vWidgets[iWidget].m_strValue);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief User clicked add - add the entered settings into a new widget.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::OnWidgetAdd(wxCommandEvent& event)
{
	LCDprocWidgetInfo cWidgetInfo;
	int iScreen;
	
	iScreen = m_pctlScreenSelection->FindString(m_pctlScreenSelection->GetValue());
	
	if (iScreen == wxNOT_FOUND || iScreen < 0)
	{
		LCDprocScreenInfo cScreenInfo;
		
		cScreenInfo.m_strName = m_pctlScreenSelection->GetValue();
		
		m_cActiveSettings.m_vScreens.push_back(cScreenInfo);
		
		iScreen = m_cActiveSettings.m_vScreens.size() - 1;
		
		UpdateScreenList();
		
		m_pctlScreenSelection->SetSelection(iScreen);
	}
	
	cWidgetInfo.m_iCol = atoi(m_pctlWidgetColumn->GetValue().mb_str(*wxConvCurrent));
	cWidgetInfo.m_iRow = atoi(m_pctlWidgetRow->GetValue().mb_str(*wxConvCurrent));
	cWidgetInfo.m_strType = m_pctlWidgetType->GetValue();
	cWidgetInfo.m_strValue = m_pctlWidgetContents->GetValue();
	
	m_cActiveSettings.m_vScreens[iScreen].m_vWidgets.push_back(cWidgetInfo);
	
	UpdateWidgetList();
	
	m_pctlWidgetList->SetSelection(m_pctlWidgetList->GetCount() - 1);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief User clicked update - update the settings in the selected widget
/// with what's on the screen.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::OnWidgetUpdate(wxCommandEvent& event)
{
	LCDprocWidgetInfo cWidgetInfo;
	int iScreen;
	int iWidget;
	
	iScreen = m_pctlScreenSelection->FindString(m_pctlScreenSelection->GetValue());
	
	iWidget = m_pctlWidgetList->GetSelection();
	
	if (iWidget == wxNOT_FOUND || iWidget < 0 || iScreen == wxNOT_FOUND || iScreen < 0)
		return;
	
	cWidgetInfo.m_iCol = atoi(m_pctlWidgetColumn->GetValue().mb_str(*wxConvCurrent));
	cWidgetInfo.m_iRow = atoi(m_pctlWidgetRow->GetValue().mb_str(*wxConvCurrent));
	cWidgetInfo.m_strType = m_pctlWidgetType->GetValue();
	cWidgetInfo.m_strValue = m_pctlWidgetContents->GetValue();
	
	m_cActiveSettings.m_vScreens[iScreen].m_vWidgets[iWidget] = cWidgetInfo;
	
	UpdateWidgetList();
	
	m_pctlWidgetList->SetSelection(iWidget);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief User clicked delete - delete the selected widget.
///
/// Also, deletes the selected screen if there are no widgets left on it.
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageLCDproc::OnWidgetDelete(wxCommandEvent& event)
{
	int iScreen;
	int iWidget;
	
	iScreen = m_pctlScreenSelection->FindString(m_pctlScreenSelection->GetValue());
	
	iWidget = m_pctlWidgetList->GetSelection();
	
	if (iWidget == wxNOT_FOUND || iWidget < 0 || iScreen == wxNOT_FOUND || iScreen < 0)
		return;
	
	m_cActiveSettings.m_vScreens[iScreen].m_vWidgets.erase(m_cActiveSettings.m_vScreens[iScreen].m_vWidgets.begin() + iWidget);
	
	UpdateWidgetList();

	// check if this was the last widget
	if (m_cActiveSettings.m_vScreens[iScreen].m_vWidgets.size() == 0)
	{
		// if so, remove the entire screen
		m_cActiveSettings.m_vScreens.erase(m_cActiveSettings.m_vScreens.begin() + iScreen);

		UpdateScreenList();
	}
}


