/*
 *  Roadnav
 *
 *  PreferencesPageLCDproc.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the LCDproc page of the preferences dialog box.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef PREFERENCESPAGELCDPROC_H
#define PREFERENCESPAGELCDPROC_H

#include <wx/notebook.h>

#include "LCDprocInterface.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements the LCDproc page of the preferences dialog box
///
//////////////////////////////////////////////////////////////////////////////
class PreferencesPageLCDproc : public wxPanel
{
	public:
		PreferencesPageLCDproc(wxWindow *parent);
		void OnOk(wxCommandEvent& event);

	private:
		void OnScreenSelection(wxCommandEvent& event);
		void OnWidgetSelection(wxCommandEvent& event);
		void OnWidgetAdd(wxCommandEvent& event);
		void OnWidgetUpdate(wxCommandEvent& event);
		void OnWidgetDelete(wxCommandEvent& event);
		
		void UpdateScreenList();
		void UpdateWidgetList();

		/// Check box indicating if LCDproc support is enabled or not.
		wxCheckBox * m_pctlEnableLCDproc;

		/// Text control where the user can enter the host and port of the LCDproc server.
		wxTextCtrl * m_pctlHostAndPort;

		/// Screen selection combo box. User may type in new screen names or use the drop down feature.
		wxComboBox * m_pctlScreenSelection;

		/// List box containing the widgets for this screen.
		wxListBox * m_pctlWidgetList;
		


		/// Row number of this widget. 1 = top row, 2 = second row, etc.
		wxTextCtrl * m_pctlWidgetRow;

		/// Column number of this widget. 1 = leftmost column, 2 = second column, etc.
		wxTextCtrl * m_pctlWidgetColumn;

		/// Combo box containing the type of this widget.
		wxComboBox * m_pctlWidgetType;

		/// Combo box containing the value of this widget. May be a mangled variable name or static text.
		wxComboBox * m_pctlWidgetContents;
		
		/// Contains a copy of the entered settings. Made effective using SetLCDprocSettings in OnOK.
		LCDprocSettings m_cActiveSettings;

		DECLARE_EVENT_TABLE()
};

#endif
