/*
 *  Roadnav
 *  PreferencesPageProxy.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the proxy page of the preferences dialog box.
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#pragma warning(disable: 4800)
#endif

#include <wx/wx.h>

#include <vector>

#include "libroadnav/Map.h"
#include "libroadnav/DownloadFiles.h"
#include "libroadnav/MapSupport.h"

#include "App.h"
#include "PreferencesPageProxy.h"
#include "SerialIO.h"
#include "wxSkinnableFrame.h"
#include "Support.h"

using namespace std;

enum
{
	idUseSystemProxySettings
};

//////////////////////////////////////////////////////////////////////////////
///
/// PreferencesPageProxy event table
///
//////////////////////////////////////////////////////////////////////////////
BEGIN_EVENT_TABLE(PreferencesPageProxy, wxPanel)
	EVT_CHECKBOX(idUseSystemProxySettings, PreferencesPageProxy::OnUseSystemProxySettings)
END_EVENT_TABLE()

//////////////////////////////////////////////////////////////////////////////
///
/// \brief PreferencesPageProxy constructor - create controls and initialize them
///
//////////////////////////////////////////////////////////////////////////////
PreferencesPageProxy::PreferencesPageProxy(wxWindow *parent)
             : wxPanel(parent, -1, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL)
{
	wxBoxSizer * psizerWnd;
	wxFlexGridSizer * psizerGrid;
	
	psizerGrid = new wxFlexGridSizer(2, 5, 10);
	
	//////////////////////////////////////////////////////////////////////////
	// Use System Proxy Settings label
	//////////////////////////////////////////////////////////////////////////
	psizerGrid->Add(
		new wxStaticText(this, -1, wxT("Use System Proxy Settings")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Use System Proxy Settings check box
	//////////////////////////////////////////////////////////////////////////
	m_pctlUseSystemProxySettings = new wxCheckBox(this, idUseSystemProxySettings, wxT(""));
	m_pctlUseSystemProxySettings->SetValue(g_pConfig->Read(wxT("UseSystemProxySettings"), (long) 1));

	psizerGrid->Add(
		m_pctlUseSystemProxySettings, 
		0,
		wxALIGN_LEFT,
		0
	);

	//////////////////////////////////////////////////////////////////////////
	// Proxy Host Label
	//////////////////////////////////////////////////////////////////////////
	psizerGrid->Add(
		new wxStaticText(this, -1, wxT("Proxy Host")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Host Entry
	//////////////////////////////////////////////////////////////////////////
	m_pctlProxyHost = new wxTextCtrl(this, -1, g_pConfig->Read(wxT("ProxyHost"), wxT("")), wxDefaultPosition, wxSize(250, -1));

	psizerGrid->Add(
		m_pctlProxyHost,
		0,
		wxALIGN_LEFT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Port Label
	//////////////////////////////////////////////////////////////////////////
	psizerGrid->Add(
		new wxStaticText(this, -1, wxT("Proxy Port")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Port Entry
	//////////////////////////////////////////////////////////////////////////
	long lPort = 0;

	g_pConfig->Read(wxT("ProxyPort"), &lPort);
	m_pctlProxyPort = new wxTextCtrl(this, -1, wxString::Format(wxT("%ld"), lPort), wxDefaultPosition, wxSize(250, -1));

	psizerGrid->Add(
		m_pctlProxyPort,
		0,
		wxALIGN_LEFT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Username Label
	//////////////////////////////////////////////////////////////////////////
	psizerGrid->Add(
		new wxStaticText(this, -1, wxT("Proxy Username")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Username Entry
	//////////////////////////////////////////////////////////////////////////
	m_pctlProxyUsername = new wxTextCtrl(this, -1, g_pConfig->Read(wxT("ProxyUsername"), wxT("")), wxDefaultPosition, wxSize(250, -1));

	psizerGrid->Add(
		m_pctlProxyUsername,
		0,
		wxALIGN_LEFT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Password Label
	//////////////////////////////////////////////////////////////////////////
	psizerGrid->Add(
		new wxStaticText(this, -1, wxT("Proxy Password")),
		0,
		wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Proxy Password Entry
	//////////////////////////////////////////////////////////////////////////
	m_pctlProxyPassword = new wxTextCtrl(this, -1, g_pConfig->Read(wxT("ProxyPassword"), wxT("")), wxDefaultPosition, wxSize(250, -1), wxTE_PASSWORD);

	psizerGrid->Add(
		m_pctlProxyPassword,
		0,
		wxALIGN_LEFT,
		0
	);
	
	//////////////////////////////////////////////////////////////////////////
	// psizerWnd just adds a border to psizerGrid
	//////////////////////////////////////////////////////////////////////////
	
	psizerWnd = new wxBoxSizer(wxVERTICAL);
	psizerWnd->Add(
		psizerGrid,
		0,
		wxALL | wxGROW,
		10
	);
	
	//////////////////////////////////////////////////////////////////////////
	// Set up the sizer
	//////////////////////////////////////////////////////////////////////////

	psizerWnd->Fit(this);
	SetSizer(psizerWnd);
	Layout();
	psizerWnd->SetSizeHints(this);
	
	wxCommandEvent ev;
	OnUseSystemProxySettings(ev);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Ok was pressed .. save the settings
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageProxy::OnOk(wxCommandEvent& event)
{
	g_pConfig->Write(wxT("ProxyHost"), m_pctlProxyHost->GetValue());
	g_pConfig->Write(wxT("ProxyUsername"), m_pctlProxyUsername->GetValue());
	g_pConfig->Write(wxT("ProxyPassword"), m_pctlProxyPassword->GetValue());
	g_pConfig->Write(wxT("UseSystemProxySettings"), m_pctlUseSystemProxySettings->GetValue());

	long lPort = 0;
	m_pctlProxyPort->GetValue().ToLong(&lPort);
	g_pConfig->Write(wxT("ProxyPort"), lPort);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Use System Proxy Settings checkbox toggled
///
//////////////////////////////////////////////////////////////////////////////
void PreferencesPageProxy::OnUseSystemProxySettings(wxCommandEvent & event)
{
	m_pctlProxyHost->Enable(!m_pctlUseSystemProxySettings->GetValue());
	m_pctlProxyPort->Enable(!m_pctlUseSystemProxySettings->GetValue());
	m_pctlProxyUsername->Enable(!m_pctlUseSystemProxySettings->GetValue());
	m_pctlProxyPassword->Enable(!m_pctlUseSystemProxySettings->GetValue());
}
