/*
 *  Roadnav
 *
 *  PreferencesPageThemes.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the themes page of the preferences dialog box.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef PREFERENCESPAGETHEMES_H
#define PREFERENCESPAGETHEMES_H

#include <wx/notebook.h>

#include "ThemeManager.h"
#include "libroadnav/MapControlData.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Implements the Themes page of the preferences dialog box
///
//////////////////////////////////////////////////////////////////////////////
class PreferencesPageThemes : public wxPanel
{
	public:
		PreferencesPageThemes(wxWindow *parent, IMapControlData * pMapControlData, ThemeManager * pThemeManager);
		void OnOk(wxCommandEvent& event);
	
	private:
		void OnAdd(wxCommandEvent& event);
		void OnEdit(wxCommandEvent& event);
		void OnRemove(wxCommandEvent& event);
		
		int EditTheme(wxString& strTheme, MapAppearanceSettings & theme);
		void RefreshComboBoxes(const wxString & strRenameFrom = wxT(""), const wxString & strRenameTo = wxT(""));

		/// List of all themes	
		wxListBox* m_pctlThemeList;
		
		/// Theme used at night
		wxComboBox* m_pctlNightTheme;
		
		/// Theme used during the day
		wxComboBox* m_pctlDayTheme;
		
		/// Theme used in aerial photo mode
		wxComboBox* m_pctlPhotoTheme;
		
		/// Always day/always night/switch at sunrise and sunset
		wxRadioBox* m_pctlThemeUsage;

		/// Map control data
		IMapControlData * m_pMapControlData;
		
		/// Parent's theme manager
		ThemeManager * m_pParentThemeManager;
		
		/// Currently being edited theme manager
		ThemeManager m_ThemeManager;
	
		DECLARE_EVENT_TABLE()
};

#endif
