/*
 *  Roadnav
 *  SatelliteControl.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the SatelliteControl class - a control that graphically shows the 
/// detected satellites.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef SATELLITECONTROL_H
#define SATELLITECONTROL_H

#include <wx/wx.h>

#include "libroadnav/Point.h"
#include "CompassControl.h"
#include "GPSMonitorThread.h"

DECLARE_EVENT_TYPE(wxEVT_SAFE_REFRESH, -1)

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Shows the detected satellites.
///
//////////////////////////////////////////////////////////////////////////////
class SatelliteControl : public wxControl
{
	public:
		SatelliteControl();
		SatelliteControl(wxWindow* parent, wxWindowID id = -1, wxPoint pt = wxDefaultPosition, wxSize sz = wxDefaultSize);

		bool OnGPSUpdate(wxGPSEvent evGPS);
		void UpdateColors(wxColour clrForeground, wxColour clrBackground);
	
	private:
		void SafeRefresh();
		void OnSafeRefresh(wxCommandEvent & event);
		void OnPaint(wxPaintEvent& event);
		void OnEraseBackground(wxEraseEvent& event);
		
		SSatelliteInfo m_arSatellitesVisible[MAX_GPS_SATELLITES];
		int m_nSatellitesVisible;
	
		DECLARE_EVENT_TABLE()
		DECLARE_DYNAMIC_CLASS(SatelliteControl);
};

#endif
