/*
 *  Roadnav
 *  TTSFactory.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains functions used to generate TTS objects
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#pragma warning(disable: 4800)
#endif

#include <wx/wx.h>

#include "TTSFactory.h"
#include "TTS_None.h"
#include "TTS_Festival.h"
#include "TTS_SAPI5.h"
#include "TTS_Flite.h"
#include "TTS_AppleSpeech.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Constructs a TTS object of the supplied type, or a TTSTypeNone
/// if an invalid type is specified.
///
//////////////////////////////////////////////////////////////////////////////
ITTS * ConstructTTS(ETTSType eType)
{
	switch (eType)
	{
#ifdef USE_SAPI5
		case TTSTypeSAPI5:
			return new TTS_SAPI5();
#endif
		
#ifdef USE_FESTIVAL
		case TTSTypeFestival:
			return new TTS_Festival();
#endif
		
#ifdef USE_APPLESPEECH
		case TTSTypeAppleSpeech:
			return new TTS_AppleSpeech();
#endif
		
#ifdef USE_FLITE
		case TTSTypeFlite:
			return new TTS_Flite();
#endif
		
		case TTSTypeNone:
		default:
			return new TTS_None();
	}
	
	wxASSERT(0);
	return NULL;
}
