/*
 *  Roadnav
 *  TTS_AppleSpeech.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Apple built in speech services text to speech class
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#endif

#ifdef USE_APPLESPEECH

#include <wx/wx.h>

#include <ApplicationServices/ApplicationServices.h>

#include "TTS_AppleSpeech.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Initialize TTS
///
//////////////////////////////////////////////////////////////////////////////
TTS_AppleSpeech::TTS_AppleSpeech()
{
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Clean up TTS
///
//////////////////////////////////////////////////////////////////////////////
TTS_AppleSpeech::~TTS_AppleSpeech()
{
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Name of this TTS engine
///
//////////////////////////////////////////////////////////////////////////////
wxString TTS_AppleSpeech::Name()
{
	return wxT("Apple Speech");
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Say some stuff using TTS
///
//////////////////////////////////////////////////////////////////////////////
ITTS::ETTSStatus TTS_AppleSpeech::Speak(const wxString & strText)
{
	unsigned char * pscText;
	
	pscText = new unsigned char [strText.Length() + 4];
	
	CopyCStringToPascal(strText.mb_str(*wxConvCurrent), pscText);
	SpeakString(pscText);

	delete pscText;
	
	return ITTS::TTSStatusOK;
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Retrieve last error message
///
//////////////////////////////////////////////////////////////////////////////
wxString TTS_AppleSpeech::GetLastError()
{
	return wxT("");
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Retrieve engine status
///
//////////////////////////////////////////////////////////////////////////////
ITTS::ETTSStatus TTS_AppleSpeech::GetStatus()
{
	return ITTS::TTSStatusOK;
}

#endif
