/*
 *  Roadnav
 *  TTS_Flite.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Flite text to speech class
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#endif

#ifdef USE_FLITE

#include <wx/wx.h>

#include "TTS_Flite.h"

extern "C" cst_voice * register_cmu_us_kal();
extern "C" void unregister_cmu_us_kal(cst_voice *v);

cst_voice * TTS_Flite::m_pVoice = NULL;

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Initialize TTS
///
//////////////////////////////////////////////////////////////////////////////
TTS_Flite::TTS_Flite()
{
	if (!m_pVoice)
	{
		flite_init();
		m_pVoice = register_cmu_us_kal();
	}
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Clean up TTS
///
//////////////////////////////////////////////////////////////////////////////
TTS_Flite::~TTS_Flite()
{
	//unregister_cmu_us_kal(m_pVoice);
	//m_pVoice = NULL;
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Name of this TTS engine
///
//////////////////////////////////////////////////////////////////////////////
wxString TTS_Flite::Name()
{
	return wxT("Flite");
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Say some stuff using TTS
///
//////////////////////////////////////////////////////////////////////////////
ITTS::ETTSStatus TTS_Flite::Speak(const wxString & strText)
{
	if (!m_pVoice)
		return ITTS::TTSErrorDisableGPS;
		
	flite_text_to_speech(strText.mb_str(*wxConvCurrent), m_pVoice, "play");
	return ITTS::TTSStatusOK;
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Retrieve last error message
///
//////////////////////////////////////////////////////////////////////////////
wxString TTS_Flite::GetLastError()
{
	return wxT("");
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Retrieve engine status
///
//////////////////////////////////////////////////////////////////////////////
ITTS::ETTSStatus TTS_Flite::GetStatus()
{
	if (!m_pVoice)
		return ITTS::TTSErrorDisableGPS;

	return ITTS::TTSStatusOK;
}

#endif
