/*
 *  Roadnav
 *  ThemeManager.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Class used to manage themes
///
//////////////////////////////////////////////////////////////////////////////
#ifndef THEMEMANAGER_H
#define THEMEMANAGER_H

#include "libroadnav/MapAppearanceSettings.h"
#include <map>
#include <wx/config.h>

class ThemeManager
{
public:
	enum ThemeUsage { AutoSwap, // Day/Night themes swap at sunrise/set
                     Night,    // Use only night theme
                     Day };    // Use only day theme
	ThemeManager();
	void AddTheme(const wxString& strTheme, MapAppearanceSettings & theme);
	void UpdateTheme(const wxString& strTheme, MapAppearanceSettings & theme);
	const MapAppearanceSettings & GetTheme(const wxString& strTheme) const;
	MapAppearanceSettings & GetTheme(const wxString& strTheme);
	void RemoveTheme(const wxString& strTheme);
	wxInt16 GetThemeCount() const;
	void RenameTheme(const wxString& strOldName,const wxString& strNewName);
	
	void SetThemeUsage(ThemeUsage usage);
	ThemeUsage GetThemeUsage() const;

	wxArrayString GetThemeNames() const;

	void SetNightTheme(const wxString& strTheme);
	wxString GetNightThemeName() const;
	const MapAppearanceSettings & GetNightTheme() const;

	void SetDayTheme(const wxString& strTheme);
	wxString GetDayThemeName() const;
	const MapAppearanceSettings & GetDayTheme() const;
	
	void SetPhotoTheme(const wxString& strTheme);
	wxString GetPhotoThemeName() const;
	const MapAppearanceSettings & GetPhotoTheme() const;

   void Load(wxConfigBase* pConfig);
   void Save(wxConfigBase* pConfig) const;

private:
	std::map<wxString,MapAppearanceSettings> m_mapThemes;
	wxString m_strNightTheme;
	wxString m_strDayTheme;
	wxString m_strPhotoTheme;
	ThemeUsage m_ThemeUsage;
};

#endif // THEMEMANAGER_H
