/*
 *  Roadnav
 *  WaypointDialog.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// The WaypointDialog class contains a dialog box that allows the user
/// user the enter an address.
///
/// It also contains code to parse that address.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef WAYPOINTDIALOG_H
#define WAYPOINTDIALOG_H

#include "libroadnav/Address.h"
#include "libroadnav/MapControl.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Waypoint selection dialog box
///
//////////////////////////////////////////////////////////////////////////////
class WaypointDialog : public wxDialog
{
	public:
		WaypointDialog(wxWindow *parent, MapControl * pctlMap, wxFont * pFont = NULL, wxString strTitleBar = wxT("Enter an address"), wxString strTitleText = wxT("Please choose a waypoint"));
		~WaypointDialog();
		MapMarker GetMarker();
		int ShowModal();
	
		/// specify the window title in this variable
		wxString m_strTitle;
	
	private:
		void OnOk(wxCommandEvent& event);
		void OnCancel(wxCommandEvent& event);
		void OnAdvanced(wxCommandEvent& event);

		/// List box containing previously entered addresses
		wxListBox * m_ctlOldAddresses;
		
		MapControl * m_pctlMap;
		
		MapMarker m_cMarker;
		
		wxFont m_cFont;

		DECLARE_EVENT_TABLE()
};

#endif
