/*
 *  Roadnav
 *  WhatsNearBy.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// The what's nearby miniframe shows a list of landmarks that are near the
/// current coordinates.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef WHATSNEARBY_H
#define WHATSNEARBY_H

#include <wx/listctrl.h>

#include "libroadnav/Point.h"
#include "libroadnav/MapControlData.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief The what's nearby miniframe shows a list of landmarks that are near the
/// current coordinates.
///
//////////////////////////////////////////////////////////////////////////////
class WhatsNearByFrame : public wxFrame
{
	public:
		WhatsNearByFrame(class MapFrame *parent, wxWindowID id, IMapControlData * pcMapControlData);
		~WhatsNearByFrame();
	
		void SetCenter(Point ptCenter);
		Point GetCenter();

		Point GetSelectedCoordinates();
		IMapControlData * GetMapControlData();

		virtual bool SetBackgroundColour(const wxColour& colour);
		virtual bool SetForegroundColour(const wxColour& colour);
		virtual bool SetFont(const wxFont& font);
		
		/// Pointer to parent
		class MapFrame * m_pfrmMap;

	private:
		void OnClose(wxCloseEvent& event);
		void OnListDoubleClick(wxListEvent & event);

		void UpdateList();
		void SetItemText(int iRow, int iCol, wxString strText);

		/// List control with all of the nearby landmarks
		wxListCtrl * m_pctlList;
	
		/// Center coordinates
		Point m_ptCenter;
	
		/// Maximum distance in miles from center coordinates to show
		/// landmarks from.
		double m_fMaxDistance;

		IMapControlData * m_pcMapControlData;
	
		DECLARE_EVENT_TABLE()
};

#endif
