/*
 *  Roadnav
 *  wxBitmapButtonNoBackground.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains wxBitmapButtonNoBackground - a class similar to wxBitmapButton,
/// but one that does not draw any sort of background and is therefore
/// suitable for arbitrary shaped buttons.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef WXBITMAPBUTTONNOBACKGROUND_H
#define WXBITMAPBUTTONNOBACKGROUND_H

#include <wx/wx.h>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief A class similar to wxBitmapButton, but one that does not draw any 
/// sort of background and is therefore suitable for arbitrary shaped buttons.
///
//////////////////////////////////////////////////////////////////////////////
class wxBitmapButtonNoBackground : public wxControl
{
	public:
		wxBitmapButtonNoBackground(wxWindow* parent, wxWindowID id, const wxBitmap& bitmap, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxBU_AUTODRAW, const wxValidator& validator = wxDefaultValidator, const wxString& name = wxT("button"));
		void SetBitmapSelected(const wxBitmap& bitmap);
		void SetBitmapActive(const wxBitmap & bitmap);
		void SetActive(bool bActive);

	private:
		void OnEraseBackground(wxEraseEvent& event);
		void OnPaint(wxPaintEvent& event);
		void OnLeftUp(wxMouseEvent& event);
		void OnLeftDown(wxMouseEvent& event);
		void OnMouseLeaveWindow(wxMouseEvent& event);

		/// Parent window
		wxWindow * m_pParent;

		/// ID of this control
		wxWindowID m_iID;

		/// Bitmap drawn when button is not depressed
		wxBitmap m_bmpDefault;
		
		/// Bitmap drawn when button is pressed
		wxBitmap m_bmpSelected;

		/// Bitmap drawn when button is active
		wxBitmap m_bmpActive;

		/// true = left mouse button was pressed on this button
		bool m_bSelected;

		/// true = active, false = not active
		bool m_bActive;
		
		DECLARE_EVENT_TABLE()
};

#endif
