/*
 *  Roadnav
 *  wxBitmapControl.cpp
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains wxBitmapControl - a class similar to wxStaticBitmap, but
/// without the quirks.
///
//////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef _MSC_VER
#pragma warning(disable: 4786)
#endif

#include <wx/wx.h>

#include "wxBitmapControl.h"

BEGIN_EVENT_TABLE(wxBitmapControl, wxControl)
	EVT_ERASE_BACKGROUND(wxBitmapControl::OnEraseBackground)
	EVT_PAINT(wxBitmapControl::OnPaint)
END_EVENT_TABLE()

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Constructor - takes same parameters as wxStaticBitmap.
///
//////////////////////////////////////////////////////////////////////////////
wxBitmapControl::wxBitmapControl( wxWindow* parent, 
														wxWindowID id, 
														const wxBitmap& bitmap, 
														const wxPoint& pos, 
														const wxSize& size, 
														long style, 
														const wxString& name)
{
	m_pParent = parent;
	m_bmpDefault = bitmap;

	Create(
				parent, 
				id, 
				pos, 
				size, 
#if wxCHECK_VERSION(2, 5, 0)
				wxNO_BORDER
#else
				0
#endif
				);
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Handles erase background message - does nothing.
///
//////////////////////////////////////////////////////////////////////////////
void wxBitmapControl::OnEraseBackground(wxEraseEvent& event)
{
}

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Paint image.
///
//////////////////////////////////////////////////////////////////////////////
void wxBitmapControl::OnPaint(wxPaintEvent& event)
{
	wxPaintDC dc(this);

	dc.DrawBitmap(m_bmpDefault, 0, 0, true);
}

