/*
 *  Roadnav
 *  wxBitmapControl.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of version 2 of the GNU General Public License
 *  as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains wxBitmapControl - a class similar to wxStaticBitmap, but
/// without the quirks.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef WXBITMAPCONTROL_H
#define WXBITMAPCONTROL_H

#include <wx/wx.h>

//////////////////////////////////////////////////////////////////////////////
///
/// \brief A class similar to wxStaticBitmap, but without the quirks.
///
/// wxStaticBitmap cannot be used with wxSkinnableFrame due to some odd
/// z-order and mouse event issues under Win32.
///
//////////////////////////////////////////////////////////////////////////////
class wxBitmapControl : public wxControl
{
	public:
		wxBitmapControl(wxWindow* parent, wxWindowID id, const wxBitmap& bitmap, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = 0, const wxString& name = wxT("staticBitmap"));

	private:
		void OnEraseBackground(wxEraseEvent& event);
		void OnPaint(wxPaintEvent& event);

		/// Parent window
		wxWindow * m_pParent;

		/// Bitmap drawn when button is not depressed
		wxBitmap m_bmpDefault;
		
		DECLARE_EVENT_TABLE()
};

#endif
